@@ -1,12 +1,12 @@
 package PHPLive::Report;
 
-our $DATE = '2014-08-16'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -14,6 +14,11 @@ our @EXPORT_OK = qw(parse_phplive_transcript %reports %legends);
 
 our %SPEC;
 
+$SPEC{':package'} = {
+    v => 1.1,
+    summary => 'Generate reports for PHP Live!',
+};
+
 our %reports = (
     chat_report => 'Chat reports',
     chat_report_by_dept => 'Chat report by department',
@@ -115,6 +120,7 @@ sub _recap_transcripts {
 
 $SPEC{gen_phplive_reports} = {
     v => 1.1,
+    summary => 'Generate reports for PHP Live!',
     args => {
         dbh     => {schema=>'obj*', req=>1},
         year    => {schema=>'int*', req=>1},
@@ -262,7 +268,7 @@ PHPLive::Report - Generate reports for PHP Live!
 
 =head1 VERSION
 
-This document describes version 0.04 of PHPLive::Report (from Perl distribution PHPLive-Report), released on 2014-08-16.
+This document describes version 0.05 of PHPLive::Report (from Perl distribution PHPLive-Report), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
@@ -280,6 +286,8 @@ for your PHP Live! installation.
 
 =head2 gen_phplive_reports(%args) -> any
 
+{en_US Generate reports for PHP Live!}.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -292,17 +300,17 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
- (any)
+Return value:  (any)
 
 
 =head2 parse_phplive_transcript($transcript) -> any
 
+{en_US 
 The C<plain> column in C<p_transcripts> table stores the actual chat transcript.
 Entities characters like C<< E<lt> >> and C<< E<gt> >> are HTML-entities-escaped (becoming C<&lt;>
 and C<&gt;>). Multiple lines are squished together into a single line. No
 timestamp is recorded for each message.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -312,29 +320,7 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
- (any)
-
-=head1 TODO
-
-=over
-
-=item * Add operator reports
-
-avg_simul_chats
-
-=item * Add department reports
-
-=item * Add report: monthly number of chats against hour of day
-
-With bar chart.
-
-=item * Add report: number of chats against day of week
-
-With bar chart.
-
-=back
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -342,7 +328,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/PHPLive-Re
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-PHPLive-Report>.
+Source repository is at L<https://github.com/perlancar/perl-PHPLive-Report>.
 
 =head1 BUGS
 
@@ -354,11 +340,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
